@@ -16,7 +16,7 @@ import sys
 log = getLogger(__name__)
 
 
-class _Bug(object):
+class Bug(object):
     '''A container object for a bug report. Requires a Bugzilla instance -
     every Bug is on a Bugzilla, obviously.
     Optional keyword args:
@@ -25,7 +25,7 @@ class _Bug(object):
                       you can read any attributes or make modifications to this
                       bug.
     '''
-    def __init__(self, bugzilla, bug_id=None, dict=None, autorefresh=True):
+    def __init__(self, bugzilla, bug_id=None, dict=None, autorefresh=False):
         # pylint: disable=redefined-builtin
         # API had pre-existing issue that we can't change ('dict' usage)
 
@@ -102,7 +102,12 @@ class _Bug(object):
             self.refresh(extra_fields=[name])
             refreshed = True
 
-        raise AttributeError("Bug object has no attribute '%s'" % name)
+        msg = ("Bug object has no attribute '%s'." % name)
+        if not self.autorefresh:
+            msg += ("\nIf '%s' is a bugzilla attribute, it may not have "
+                    "been cached when the bug was fetched. You may want "
+                    "to adjust your include_fields for getbug/query." % name)
+        raise AttributeError(msg)
 
     def refresh(self, include_fields=None, exclude_fields=None,
         extra_fields=None):
@@ -171,17 +176,14 @@ class _Bug(object):
     # Modify bug status #
     #####################
 
-    def setstatus(self, status, comment=None, private=False,
-                  private_in_it=False, nomail=False):
+    def setstatus(self, status, comment=None, private=False):
         '''
         Update the status for this bug report.
         Commonly-used values are ASSIGNED, MODIFIED, and NEEDINFO.
 
         To change bugs to CLOSED, use .close() instead.
         '''
-        ignore = private_in_it
-        ignore = nomail
-
+        # Note: fedora bodhi uses this function
         vals = self.bugzilla.build_update(status=status,
                                           comment=comment,
                                           comment_private=private)
@@ -190,8 +192,7 @@ class _Bug(object):
         return self.bugzilla.update_bugs(self.bug_id, vals)
 
     def close(self, resolution, dupeid=None, fixedin=None,
-              comment=None, isprivate=False,
-              private_in_it=False, nomail=False):
+              comment=None, isprivate=False):
         '''Close this bug.
         Valid values for resolution are in bz.querydefaults['resolution_list']
         For bugzilla.redhat.com that's:
@@ -205,9 +206,7 @@ class _Bug(object):
         You can optionally add a comment while closing the bug. Set 'isprivate'
           to True if you want that comment to be private.
         '''
-        ignore = private_in_it
-        ignore = nomail
-
+        # Note: fedora bodhi uses this function
         vals = self.bugzilla.build_update(comment=comment,
                                           comment_private=isprivate,
                                           resolution=resolution,
@@ -223,7 +222,7 @@ class _Bug(object):
     # Modify bug emails #
     #####################
 
-    def setassignee(self, assigned_to=None, reporter=None,
+    def setassignee(self, assigned_to=None,
                     qa_contact=None, comment=None):
         '''
         Set any of the assigned_to or qa_contact fields to a new
@@ -236,9 +235,6 @@ class _Bug(object):
 
         Returns [bug_id, mailresults].
         '''
-        if reporter:
-            raise ValueError("reporter can not be changed")
-
         if not (assigned_to or qa_contact):
             raise ValueError("You must set one of assigned_to "
                              " or qa_contact")
@@ -273,30 +269,22 @@ class _Bug(object):
         return self.bugzilla.update_bugs(self.bug_id, vals)
 
 
-    ###############
-    # Add comment #
-    ###############
+    ####################
+    # comment handling #
+    ####################
 
-    def addcomment(self, comment, private=False,
-                   timestamp=None, worktime=None, bz_gid=None):
+    def addcomment(self, comment, private=False):
         '''
         Add the given comment to this bug. Set private to True to mark this
         comment as private.
         '''
-        ignore = timestamp
-        ignore = bz_gid
-        ignore = worktime
-
+        # Note: fedora bodhi uses this function
         vals = self.bugzilla.build_update(comment=comment,
                                           comment_private=private)
         log.debug("addcomment: update=%s", vals)
 
         return self.bugzilla.update_bugs(self.bug_id, vals)
 
-    ################
-    # Get comments #
-    ################
-
     def getcomments(self):
         '''
         Returns an array of comment dictionaries for this bug
@@ -304,86 +292,6 @@ class _Bug(object):
         comment_list = self.bugzilla.get_comments([self.bug_id])
         return comment_list['bugs'][str(self.bug_id)]['comments']
 
-    ##########################
-    # Get/set bug whiteboard #
-    ##########################
-
-    def _dowhiteboard(self, text, which, action, comment, private):
-        '''
-        Update the whiteboard given by 'which' for the given bug.
-        '''
-        if which not in ["status", "qa", "devel", "internal"]:
-            raise ValueError("Unknown whiteboard type '%s'" % which)
-
-        if not which.endswith('_whiteboard'):
-            which = which + '_whiteboard'
-        if which == "status_whiteboard":
-            which = "whiteboard"
-
-        if action != 'overwrite':
-            wb = getattr(self, which, '').strip()
-            tags = wb.split()
-
-            sep = " "
-            for t in tags:
-                if t.endswith(","):
-                    sep = ", "
-
-            if action == 'prepend':
-                text = text + sep + wb
-            elif action == 'append':
-                text = wb + sep + text
-            else:
-                raise ValueError("Unknown whiteboard action '%s'" % action)
-
-        updateargs = {which: text}
-        vals = self.bugzilla.build_update(comment=comment,
-                                          comment_private=private,
-                                          **updateargs)
-        log.debug("_updatewhiteboard: update=%s", vals)
-
-        self.bugzilla.update_bugs(self.bug_id, vals)
-
-
-    def appendwhiteboard(self, text, which='status',
-                         comment=None, private=False):
-        '''Append the given text (with a space before it) to the given
-        whiteboard. Defaults to using status_whiteboard.'''
-        self._dowhiteboard(text, which, "append", comment, private)
-
-    def prependwhiteboard(self, text, which='status',
-                          comment=None, private=False):
-        '''Prepend the given text (with a space following it) to the given
-        whiteboard. Defaults to using status_whiteboard.'''
-        self._dowhiteboard(text, which, "prepend", comment, private)
-
-    def setwhiteboard(self, text, which='status',
-                      comment=None, private=False):
-        '''Overwrites the contents of the given whiteboard with the given text.
-        Defaults to using status_whiteboard.'''
-        self._dowhiteboard(text, which, "overwrite", comment, private)
-
-    def addtag(self, tag, which='status'):
-        '''Adds the given tag to the given bug.'''
-        whiteboard = self.getwhiteboard(which)
-        if whiteboard:
-            self.appendwhiteboard(tag, which)
-        else:
-            self.setwhiteboard(tag, which)
-
-    def gettags(self, which='status'):
-        '''Get a list of tags (basically just whitespace-split the given
-        whiteboard)'''
-        return self.getwhiteboard(which).split()
-
-    def deltag(self, tag, which='status'):
-        '''Removes the given tag from the given bug.'''
-        tags = self.gettags(which)
-        for t in tags:
-            if t.strip(",") == tag:
-                tags.remove(t)
-        self.setwhiteboard(' '.join(tags), which)
-
 
     #####################
     # Get/Set bug flags #
@@ -429,6 +337,21 @@ class _Bug(object):
 
         return f[0]['status']
 
+    def updateflags(self, flags):
+        """
+        Thin wrapper around build_update(flags=X). This only handles simple
+        status changes, anything like needinfo requestee needs to call
+        build_update + update_bugs directly
+
+        :param flags: Dictionary of the form {"flagname": "status"}, example
+            {"needinfo": "?", "devel_ack": "+"}
+        """
+        flaglist = []
+        for key, value in flags.items():
+            flaglist.append({"name": key, "status": value})
+        return self.bugzilla.update_bugs([self.bug_id],
+            self.bugzilla.build_update(flags=flaglist))
+
 
     ########################
     # Experimental methods #
@@ -448,33 +371,14 @@ class _Bug(object):
 
         return [a["id"] for a in attachments]
 
-    def get_history(self):
+    def get_history_raw(self):
         '''
         Experimental. Get the history of changes for this bug.
         '''
-        return self.bugzilla.bugs_history([self.bug_id])
-
-    ######################
-    # Deprecated methods #
-    ######################
-
-    def getwhiteboard(self, which='status'):
-        '''
-        Deprecated. Use bug.qa_whiteboard, bug.devel_whiteboard, etc.
-        '''
-        return getattr(self, "%s_whiteboard" % which)
-
-    def updateflags(self, flags):
-        '''
-        Deprecated, use bugzilla.update_flags() directly
-        '''
-        flaglist = []
-        for key, value in flags.items():
-            flaglist.append({"name": key, "status": value})
-        return self.bugzilla.update_flags(self.bug_id, flaglist)
+        return self.bugzilla.bugs_history_raw([self.bug_id])
 
 
-class _User(object):
+class User(object):
     '''Container object for a bugzilla User.
 
     :arg bugzilla: Bugzilla instance that this User belongs to.
