@@ -11,12 +11,12 @@
 
 from logging import getLogger
 
-from .bugzilla4 import Bugzilla44 as _parent
+from .base import Bugzilla
 
 log = getLogger(__name__)
 
 
-class RHBugzilla(_parent):
+class RHBugzilla(Bugzilla):
     '''
     Bugzilla class for connecting Red Hat's forked bugzilla instance,
     bugzilla.redhat.com
@@ -31,29 +31,7 @@ class RHBugzilla(_parent):
     This class was written using bugzilla.redhat.com's API docs:
     https://bugzilla.redhat.com/docs/en/html/api/
     '''
-
-    def __init__(self, *args, **kwargs):
-        """
-        @rhbz_back_compat: If True, convert parameters to the format they were
-            in prior RHBZ upgrade in June 2012. Mostly this replaces lists
-            with comma separated strings, and alters groups and flags.
-            Default is False. Please don't use this in new code, just update
-            your scripts.
-        @multicall: Unused nowadays, will be removed in the future
-        """
-        # 'multicall' is no longer used, just ignore it
-        multicall = kwargs.pop("multicall", None)
-        self.rhbz_back_compat = bool(kwargs.pop("rhbz_back_compat", False))
-
-        if multicall is not None:
-            log.warn("multicall is unused and will be removed in a "
-                "future release.")
-
-        if self.rhbz_back_compat:
-            log.warn("rhbz_back_compat will be removed in a future release.")
-
-        _parent.__init__(self, *args, **kwargs)
-
+    def _init_class_state(self):
         def _add_both_alias(newname, origname):
             self._add_field_alias(newname, origname, is_api=False)
             self._add_field_alias(origname, newname, is_bug=False)
@@ -128,7 +106,7 @@ class RHBugzilla(_parent):
         get_sub_component()
         get_alias()
 
-        vals = _parent.build_update(self, **kwargs)
+        vals = Bugzilla.build_update(self, **kwargs)
         vals.update(adddict)
 
         return vals
@@ -173,6 +151,8 @@ class RHBugzilla(_parent):
             'bug_ids': self._listify(bug_ids),
             'external_bugs': [param_dict],
         }
+
+        log.debug("Calling ExternalBugs.add_external_bug(%s)", params)
         return self._proxy.ExternalBugs.add_external_bug(params)
 
     def update_external_tracker(self, ids=None, ext_type_id=None,
@@ -220,6 +200,8 @@ class RHBugzilla(_parent):
             params['ext_description'] = ext_description
         if ext_priority is not None:
             params['ext_priority'] = ext_priority
+
+        log.debug("Calling ExternalBugs.update_external_bug(%s)", params)
         return self._proxy.ExternalBugs.update_external_bug(params)
 
     def remove_external_tracker(self, ids=None, ext_type_id=None,
@@ -256,6 +238,8 @@ class RHBugzilla(_parent):
             params['ext_bz_bug_id'] = self._listify(ext_bz_bug_id)
         if bug_ids is not None:
             params['bug_ids'] = self._listify(bug_ids)
+
+        log.debug("Calling ExternalBugs.remove_external_bug(%s)", params)
         return self._proxy.ExternalBugs.remove_external_bug(params)
 
 
@@ -289,7 +273,8 @@ class RHBugzilla(_parent):
 
         # We need to do this for users here for users that
         # don't call build_query
-        self._convert_include_field_list(query['include_fields'])
+        query.update(self._process_include_fields(query["include_fields"],
+            None, None))
 
         if old != query:
             log.debug("RHBugzilla pretranslated query to: %s", query)
@@ -325,227 +310,39 @@ class RHBugzilla(_parent):
                     values += vallist
                 bug['sub_component'] = " ".join(values)
 
-        if not self.rhbz_back_compat:
-            return
+    def build_external_tracker_boolean_query(self, *args, **kwargs):
+        ignore1 = args
+        ignore2 = kwargs
+        raise RuntimeError("Building external boolean queries is "
+            "no longer supported. Please build a URL query "
+            "via the bugzilla web UI and pass it to 'query --from-url' "
+            "or url_to_query()")
 
-        if 'flags' in bug and isinstance(bug["flags"], list):
-            tmpstr = []
-            for tmp in bug['flags']:
-                tmpstr.append("%s%s" % (tmp['name'], tmp['status']))
-
-            bug['flags'] = ",".join(tmpstr)
-
-        if 'blocks' in bug and isinstance(bug["blocks"], list):
-            # Aliases will handle the 'blockedby' and 'blocked' back compat
-            bug['blocks'] = ','.join([str(b) for b in bug['blocks']])
-
-        if 'keywords' in bug and isinstance(bug["keywords"], list):
-            bug['keywords'] = ','.join(bug['keywords'])
-
-        if 'alias' in bug and isinstance(bug["alias"], list):
-            bug['alias'] = ','.join(bug['alias'])
-
-        if ('groups' in bug and
-            isinstance(bug["groups"], list) and
-            len(bug["groups"]) > 0 and
-            isinstance(bug["groups"][0], str)):
-            # groups went to the opposite direction: it got simpler
-            # instead of having name, ison, description, it's now just
-            # an array of strings of the groups the bug belongs to
-            # we're emulating the old behaviour here
-            tmp = []
-            for g in bug['groups']:
-                t = {}
-                t['name'] = g
-                t['description'] = g
-                t['ison'] = 1
-                tmp.append(t)
-            bug['groups'] = tmp
-
-    def build_external_tracker_boolean_query(
-            self, ext_type_description=None, ext_type_url=None,
-            ext_bz_bug_id=None, ext_status=None):
-        """
-        Helper method to build a boolean query to find bugs that contain an
-        external tracker.
-
-        All parameters that are None will be ignored when building the query.
-
-        ext_type_description: The external tracker description as used by
-            Bugzilla.
-        ext_type_url: The external tracker url as used by Bugzilla.
-        ext_bz_bug_id: The external bug id (ie: the bug number in the
-            external tracker).
-        ext_status: The status of the external bug.
-        """
-        parts = []
-
-        if ext_type_description is not None:
-            parts.append(
-                'external_bugzilla.description-equals-{0:s}'.format(
-                    ext_type_description))
-
-        if ext_type_url is not None:
-            parts.append(
-                'external_bugzilla.url-equals-{0:s}'.format(ext_type_url))
-
-        if ext_bz_bug_id is not None:
-            id_str = str(ext_bz_bug_id)
-            parts.append(
-                'ext_bz_bug_map.ext_bz_bug_id-equals-{0:s}'.format(id_str))
-
-        if ext_status is not None:
-            parts.append(
-                'ext_bz_bug_map.ext_status-equals-{0:s}'.format(ext_status))
-
-        return ' & '.join(parts)
 
     def build_query(self, **kwargs):
-        query = {}
+        # We previously accepted a text format to approximate boolean
+        # queries, and only for RHBugzilla. Upstream bz has --from-url
+        # support now, so point people to that instead so we don't have
+        # to document and maintain this logic anymore
+        def _warn_bool(kwkey):
+            vallist = self._listify(kwargs.get(kwkey, None))
+            for value in vallist or []:
+                for s in value.split(" "):
+                    if s not in ["|", "&", "!"]:
+                        continue
+                    log.warn("%s value '%s' appears to use the now "
+                        "unsupported boolean formatting, your query may "
+                        "be incorrect. If you need complicated URL queries, "
+                        "look into bugzilla --from-url/url_to_query().",
+                        kwkey, value)
+                    return
 
-        def _add_key(paramname, keyname, listify=False):
-            val = kwargs.pop(paramname, None)
-            if val is None:
-                return
-            if listify:
-                val = self._listify(val)
-            query[keyname] = val
+        _warn_bool("fixed_in")
+        _warn_bool("blocked")
+        _warn_bool("dependson")
+        _warn_bool("flag")
+        _warn_bool("qa_whiteboard")
+        _warn_bool("devel_whiteboard")
+        _warn_bool("alias")
 
-        def add_longdesc():
-            val = kwargs.pop("long_desc", None)
-            if val is None:
-                return
-
-            query["query_format"] = "advanced"
-            query["longdesc"] = val
-            query["longdesc_type"] = "allwordssubstr"
-
-        def add_email(key, count):
-            value = kwargs.pop(key, None)
-            if value is None:
-                return count
-
-            query["query_format"] = "advanced"
-            query['email%i' % count] = value
-            query['email%s%i' % (key, count)] = True
-            query['emailtype%i' % count] = kwargs.get("emailtype", "substring")
-            return count + 1
-
-        def bool_smart_split(boolval):
-            # This parses the CLI command syntax, but we only want to
-            # do space splitting if the space is actually part of a
-            # boolean operator
-            boolchars = ["|", "&", "!"]
-            add = ""
-            retlist = []
-
-            for word in boolval.split(" "):
-                if word.strip() in boolchars:
-                    word = word.strip()
-                    if add:
-                        retlist.append(add)
-                        add = ""
-                    retlist.append(word)
-                else:
-                    if add:
-                        add += " "
-                    add += word
-
-            if add:
-                retlist.append(add)
-            return retlist
-
-        def add_boolean(kwkey, key, bool_id):
-            value = self._listify(kwargs.pop(kwkey, None))
-            if value is None:
-                return bool_id
-
-            query["query_format"] = "advanced"
-            for boolval in value:
-                and_count = 0
-                or_count = 0
-
-                def make_bool_str(prefix):
-                    # pylint: disable=cell-var-from-loop
-                    return "%s%i-%i-%i" % (prefix, bool_id,
-                                           and_count, or_count)
-
-                for par in bool_smart_split(boolval):
-                    field = None
-                    fval = par
-                    typ = kwargs.get("booleantype", "substring")
-
-                    if par == "&":
-                        and_count += 1
-                    elif par == "|":
-                        or_count += 1
-                    elif par == "!":
-                        query['negate%i' % bool_id] = 1
-                    elif not key:
-                        if par.find('-') == -1:
-                            raise RuntimeError('Malformed boolean query: %s' %
-                                               value)
-
-                        args = par.split('-', 2)
-                        field = args[0]
-                        typ = args[1]
-                        fval = None
-                        if len(args) == 3:
-                            fval = args[2]
-                    else:
-                        field = key
-
-                    query[make_bool_str("field")] = field
-                    if fval:
-                        query[make_bool_str("value")] = fval
-                    query[make_bool_str("type")] = typ
-
-                bool_id += 1
-            return bool_id
-
-        # Use fancy email specification for RH bugzilla. It isn't
-        # strictly required, but is more powerful, and it is what
-        # bin/bugzilla historically generated. This requires
-        # query_format='advanced' which is an RHBZ only XMLRPC extension
-        email_count = 1
-        email_count = add_email("cc", email_count)
-        email_count = add_email("assigned_to", email_count)
-        email_count = add_email("reporter", email_count)
-        email_count = add_email("qa_contact", email_count)
-
-        chart_id = 0
-        chart_id = add_boolean("fixed_in", "cf_fixed_in", chart_id)
-        chart_id = add_boolean("blocked", "blocked", chart_id)
-        chart_id = add_boolean("dependson", "dependson", chart_id)
-        chart_id = add_boolean("flag", "flagtypes.name", chart_id)
-        chart_id = add_boolean("qa_whiteboard", "cf_qa_whiteboard", chart_id)
-        chart_id = add_boolean("devel_whiteboard", "cf_devel_whiteboard",
-                               chart_id)
-        chart_id = add_boolean("alias", "alias", chart_id)
-        chart_id = add_boolean("boolean_query", None, chart_id)
-
-        add_longdesc()
-
-        _add_key("quicksearch", "quicksearch")
-        _add_key("savedsearch", "savedsearch")
-        _add_key("savedsearch_sharer_id", "sharer_id")
-        _add_key("sub_component", "sub_components", listify=True)
-
-        extra_fields = self._convert_include_field_list(
-            kwargs.pop('extra_fields', None))
-        if extra_fields:
-            query["extra_fields"] = extra_fields
-
-        newquery = _parent.build_query(self, **kwargs)
-        query.update(newquery)
-        self.pre_translation(query)
-        return query
-
-
-# Just for API back compat
-class RHBugzilla3(RHBugzilla):
-    pass
-
-
-class RHBugzilla4(RHBugzilla):
-    pass
+        return Bugzilla.build_query(self, **kwargs)
