@@ -11,11 +11,8 @@ Unit tests for building query strings with bin/bugzilla
 
 from __future__ import print_function
 
-import atexit
-import logging
 import os
-import shutil
-import sys
+import tempfile
 import unittest
 
 import bugzilla
@@ -29,22 +26,6 @@ class MiscCLI(unittest.TestCase):
     """
     maxDiff = None
 
-    def testManPageGeneration(self):
-        try:
-            # If logilab found, we get some useless import warning
-            import warnings
-            warnings.simplefilter("ignore")
-
-            from logilab.common.optik_ext import ManHelpFormatter
-            ignore = ManHelpFormatter
-        except Exception:
-            e = sys.exc_info()[1]
-            print("Skipping man page test: %s" % e)
-            return
-
-        out = tests.clicomm("bugzilla --generate-man", None)
-        self.assertTrue(len(out.splitlines()) > 100)
-
     def testHelp(self):
         out = tests.clicomm("bugzilla --help", None)
         self.assertTrue(len(out.splitlines()) > 18)
@@ -63,36 +44,27 @@ class MiscAPI(unittest.TestCase):
     Test miscellaneous API bits
     """
     def testUserAgent(self):
-        b3 = bugzilla.Bugzilla3(url=None, cookiefile=None, tokenfile=None)
-        rhbz = bugzilla.RHBugzilla(url=None, cookiefile=None, tokenfile=None)
-
-        self.assertTrue(b3.user_agent.endswith("Bugzilla3"))
-        self.assertTrue(rhbz.user_agent.endswith("RHBugzilla"))
+        b3 = tests.make_bz("3.0.0")
+        self.assertTrue("python-bugzilla" in b3.user_agent)
 
     def testCookies(self):
         cookiesbad = os.path.join(os.getcwd(), "tests/data/cookies-bad.txt")
         cookieslwp = os.path.join(os.getcwd(), "tests/data/cookies-lwp.txt")
         cookiesmoz = os.path.join(os.getcwd(), "tests/data/cookies-moz.txt")
-        cookiesnew = cookieslwp + ".new"
 
-        def cleanup():
-            if os.path.exists(cookiesnew):
-                os.unlink(cookiesnew)
-        atexit.register(cleanup)
-        shutil.copy(cookieslwp, cookiesnew)
-
-        # Mozilla should be converted inplace to LWP
-        bugzilla.Bugzilla3(url=None, cookiefile=cookiesnew)
-
-        def strip_comments(content):
-            return [l for l in content.split("\n") if not l.startswith("#")]
-        self.assertEquals(
-            strip_comments(open(cookiesmoz).read()),
-            strip_comments(open(cookiesnew).read()))
+        # We used to convert LWP cookies, but it shouldn't matter anymore,
+        # so verify they fail at least
+        try:
+            tests.make_bz("3.0.0", cookiefile=cookieslwp)
+            raise AssertionError("Expected BugzillaError from parsing %s" %
+                                 os.path.basename(cookieslwp))
+        except bugzilla.BugzillaError:
+            # Expected result
+            pass
 
         # Make sure bad cookies raise an error
         try:
-            bugzilla.Bugzilla3(url=None, cookiefile=cookiesbad)
+            tests.make_bz("3.0.0", cookiefile=cookiesbad)
             raise AssertionError("Expected BugzillaError from parsing %s" %
                                  os.path.basename(cookiesbad))
         except bugzilla.BugzillaError:
@@ -100,7 +72,48 @@ class MiscAPI(unittest.TestCase):
             pass
 
         # Mozilla should 'just work'
-        bugzilla.Bugzilla3(url=None, cookiefile=cookiesmoz)
+        tests.make_bz("3.0.0", cookiefile=cookiesmoz)
+
+    def test_readconfig(self):
+        # Testing for bugzillarc handling
+        bzapi = tests.make_bz("4.4.0", rhbz=True)
+        bzapi.url = "foo.example.com"
+        temp = tempfile.NamedTemporaryFile(mode="w")
+
+        content = """
+[example.com]
+foo=1
+user=test1
+password=test2"""
+        temp.write(content)
+        temp.flush()
+        bzapi.readconfig(temp.name)
+        self.assertEquals(bzapi.user, "test1")
+        self.assertEquals(bzapi.password, "test2")
+        self.assertEquals(bzapi.api_key, None)
+
+        content = """
+[foo.example.com]
+user=test3
+password=test4
+api_key=123abc
+"""
+        temp.write(content)
+        temp.flush()
+        bzapi.readconfig(temp.name)
+        self.assertEquals(bzapi.user, "test3")
+        self.assertEquals(bzapi.password, "test4")
+        self.assertEquals(bzapi.api_key, "123abc")
+
+        bzapi.url = "bugzilla.redhat.com"
+        bzapi.user = None
+        bzapi.password = None
+        bzapi.api_key = None
+        bzapi.readconfig(temp.name)
+        self.assertEquals(bzapi.user, None)
+        self.assertEquals(bzapi.password, None)
+        self.assertEquals(bzapi.api_key, None)
+
 
     def testPostTranslation(self):
         def _testPostCompare(bz, indict, outexpect):
@@ -112,8 +125,8 @@ class MiscAPI(unittest.TestCase):
             bz.post_translation({}, outdict)
             self.assertTrue(outdict == outexpect)
 
-        bug3 = bugzilla.Bugzilla3(url=None, cookiefile=None, tokenfile=None)
-        rhbz = bugzilla.RHBugzilla(url=None, cookiefile=None, tokenfile=None)
+        bug3 = tests.make_bz("3.4.0")
+        rhbz = tests.make_bz("4.4.0", rhbz=True)
 
         test1 = {
             "component": ["comp1"],
@@ -143,30 +156,5 @@ class MiscAPI(unittest.TestCase):
         out_simple["versions"] = out_simple["version"]
         out_simple["version"] = out_simple["versions"][0]
 
-        out_complex = out_simple.copy()
-        out_complex["keywords"] = ",".join(out_complex["keywords"])
-        out_complex["blocks"] = ",".join([str(b) for b in
-                                          out_complex["blocks"]])
-        out_complex["alias"] = ",".join(out_complex["alias"])
-        out_complex["groups"] = [{'description': 'redhat',
-                                  'ison': 1, 'name': 'redhat'}]
-        out_complex["flags"] = "qe_test_coverage?,rhel-6.4.0+"
-
         _testPostCompare(bug3, test1, test1)
         _testPostCompare(rhbz, test1, out_simple)
-
-        rhbz.rhbz_back_compat = True
-        _testPostCompare(rhbz, test1, out_complex)
-
-    def testRHBZInit(self):
-        # Just get us coverage when the extra values are specified
-        level = bugzilla.log.level
-        bugzilla.log.setLevel(logging.ERROR)
-        bugzilla.RHBugzilla(None, cookiefile=None, multicall=True,
-            rhbz_back_compat=True)
-        bugzilla.log.setLevel(level)
-
-    def testUnimplementedAPI(self):
-        bz3 = bugzilla.Bugzilla3(None, cookiefile=None, tokenfile=None)
-        self.assertRaises(RuntimeError, bz3.getbugfields)
-        self.assertRaises(RuntimeError, bz3.getqueryinfo)
