@@ -11,12 +11,10 @@ Unit tests for building update dictionaries with 'bugzilla modify'
 
 import unittest
 
-from bugzilla.rhbugzilla import RHBugzilla
-
 import tests
 
 
-rhbz = RHBugzilla(cookiefile=None, tokenfile=None)
+rhbz = tests.make_bz("4.4.0", rhbz=True)
 
 
 class ModifyTest(unittest.TestCase):
@@ -29,21 +27,18 @@ class ModifyTest(unittest.TestCase):
             return unittest.TestCase.assertDictEqual(self, *args, **kwargs)
         return self.assertEqual(*args, **kwargs)
 
-    def clicomm(self, argstr, out, flagsout=None, wbout=None,
-                tags_add=None, tags_rm=None):
+    def clicomm(self, argstr, out, wbout=None, tags_add=None, tags_rm=None):
         comm = "bugzilla modify --test-return-result 123456 224466 " + argstr
         # pylint: disable=unpacking-non-sequence
 
         if out is None:
             self.assertRaises(RuntimeError, tests.clicomm, comm, self.bz)
         else:
-            (mdict, fdict, wdict, tagsa, tagsr) = tests.clicomm(
+            (mdict, wdict, tagsa, tagsr) = tests.clicomm(
                 comm, self.bz, returnmain=True)
 
             if wbout:
                 self.assertDictEqual(wbout, wdict)
-            if flagsout:
-                self.assertEqual(flagsout, fdict)
             if out:
                 self.assertDictEqual(out, mdict)
             if tags_add:
@@ -83,16 +78,17 @@ class ModifyTest(unittest.TestCase):
     def testFlags(self):
         self.clicomm(
             "--flag needinfoX --flag dev_ack+ --flag qa_ack-",
-            {},
-            [{'status': 'X', 'name': 'needinfo'},
-             {'status': '+', 'name': 'dev_ack'},
-             {'status': '-', 'name': 'qa_ack'}]
+            {"flags": [
+                {'status': 'X', 'name': 'needinfo'},
+                {'status': '+', 'name': 'dev_ack'},
+                {'status': '-', 'name': 'qa_ack'}
+            ]}
         )
 
     def testWhiteboard(self):
         self.clicomm(
-            "--whiteboard tagfoo --whiteboard -tagbar",
-            {}, wbout={"status": (["tagfoo"], ["tagbar"])}
+            "--whiteboard tagfoo --whiteboard=-tagbar",
+            {}, wbout={"whiteboard": (["tagfoo"], ["tagbar"])}
         )
         self.clicomm(
             "--whiteboard =foo --whiteboard =thisone",
@@ -100,16 +96,16 @@ class ModifyTest(unittest.TestCase):
         )
 
         self.clicomm(
-            "--qa_whiteboard =yo-qa --qa_whiteboard -foo "
+            "--qa_whiteboard =yo-qa --qa_whiteboard=-foo "
             "--internal_whiteboard =internal-hey --internal_whiteboard +bar "
-            "--devel_whiteboard =devel-duh --devel_whiteboard -yay "
-            "--tags foo1 --tags -remove2",
+            "--devel_whiteboard =devel-duh --devel_whiteboard=-yay "
+            "--tags foo1 --tags=-remove2",
             {'cf_devel_whiteboard': 'devel-duh',
              'cf_internal_whiteboard': 'internal-hey',
              'cf_qa_whiteboard': 'yo-qa'}, wbout={
-                "qa": ([], ["foo"]),
-                "internal": (["bar"], []),
-                "devel": ([], ["yay"])
+                "qa_whiteboard": ([], ["foo"]),
+                "internal_whiteboard": (["bar"], []),
+                "devel_whiteboard": ([], ["yay"])
             }, tags_add=["foo1"], tags_rm=["remove2"],
         )
 
@@ -121,7 +117,7 @@ class ModifyTest(unittest.TestCase):
              'reset_qa_contact': True}
         )
         self.clicomm(
-            "--groups +foo --groups -bar,baz --groups fribby",
+            "--groups +foo --groups=-bar,baz --groups fribby",
             {'groups': {'add': ['foo', 'fribby'], 'remove': ['bar', 'baz']}}
         )
         self.clicomm(
@@ -167,7 +163,7 @@ class ModifyTest(unittest.TestCase):
             {'depends_on': {'add': [100, 200]}}
         )
         self.clicomm(
-            "--dependson -100,200",
+            "--dependson=-100,200",
             {'depends_on': {'remove': [100, 200]}}
         )
         self.clicomm(
@@ -176,7 +172,7 @@ class ModifyTest(unittest.TestCase):
         )
 
         self.clicomm(
-            "--dependson 1 --dependson -2 --dependson +3 --dependson =4",
+            "--dependson 1 --dependson=-2 --dependson +3 --dependson =4",
             {'depends_on': {'add': [1, 3], 'remove': [2], 'set': [4]}}
         )
         self.clicomm(
@@ -184,7 +180,7 @@ class ModifyTest(unittest.TestCase):
             {'blocks': {'add': [5, 7], 'remove': [6], 'set': [8, 9]}}
         )
         self.clicomm(
-            "--keywords foo --keywords -bar --keywords +baz --keywords =yay",
+            "--keywords foo --keywords=-bar --keywords +baz --keywords =yay",
             {'keywords': {'add': ["foo", "baz"],
                           'remove': ["bar"], 'set': ["yay"]}}
         )
@@ -193,7 +189,7 @@ class ModifyTest(unittest.TestCase):
 
     def testCC(self):
         self.clicomm(
-            "--cc foo@example.com --cc -minus@example.com "
+            "--cc foo@example.com --cc=-minus@example.com "
             "--cc =foo@example.com --cc +foo@example.com",
             {'cc': {'add': ['foo@example.com', "=foo@example.com",
                             "+foo@example.com"],
@@ -202,7 +198,7 @@ class ModifyTest(unittest.TestCase):
 
     def testSubComponents(self):
         self.clicomm("--component foo --sub-component 'bar baz'",
-            {"component": "foo", "sub_components": {"foo": "bar baz"}})
+            {"component": "foo", "sub_components": {"foo": ["bar baz"]}})
 
     def testSubComponentFail(self):
         self.assertRaises(ValueError, self.bz.build_update,
