@@ -25,7 +25,7 @@ else:
 
 import bugzilla
 from bugzilla import Bugzilla
-from bugzilla.base import _BugzillaToken
+from bugzilla.transport import _BugzillaTokenCache
 
 import tests
 
@@ -42,7 +42,7 @@ class BaseTest(unittest.TestCase):
     bzclass = None
 
     def _testBZClass(self):
-        bz = Bugzilla(url=self.url, cookiefile=None, tokenfile=None)
+        bz = Bugzilla(url=self.url, use_creds=False)
         self.assertTrue(bz.__class__ is self.bzclass)
 
     def _testCookieOrToken(self):
@@ -53,7 +53,7 @@ class BaseTest(unittest.TestCase):
                 return
 
         if os.path.exists(tf):
-            token = _BugzillaToken(self.url, tokenfilename=tf)
+            token = _BugzillaTokenCache(self.url, tokenfilename=tf)
             if token.value is not None:
                 return
 
@@ -65,7 +65,7 @@ class RHPartnerTest(BaseTest):
     # Despite its name, this instance is simply for bugzilla testing,
     # doesn't send out emails and is blown away occasionally. The front
     # page has some info.
-    url = tests.REDHAT_URL or "https://partner-bugzilla.redhat.com/xmlrpc.cgi"
+    url = tests.REDHAT_URL or "partner-bugzilla.redhat.com"
     bzclass = bugzilla.RHBugzilla
 
 
@@ -75,25 +75,27 @@ class RHPartnerTest(BaseTest):
         # Check a known account that likely won't ever go away
         ret = bool(bz.getuser("anaconda-maint-list@redhat.com").groupnames)
         if not ret:
-            print("\nNo admin privs, skipping %s" % funcname)
+            print("\nNo admin privs, reduced testing of %s" % funcname)
         return ret
 
-    def _check_rh_privs(self, bz, funcname, authtype, quiet=False):
-        noprivs = bool(bz.getbugs([184858]) == [None])
-        if noprivs and not quiet:
-            print("\nNo RH %s privs, skipping %s" % (authtype, funcname))
-        return not noprivs
-
-
-    test1 = BaseTest._testCookieOrToken
     test2 = BaseTest._testBZClass
 
 
-    def test3NewBugBasic(self):
+    def test00LoginState(self):
+        bz = self.bzclass(url=self.url)
+        self.assertTrue(bz.logged_in,
+            "R/W tests require cached login credentials for url=%s" % self.url)
+
+        bz = self.bzclass(url=self.url, use_creds=False)
+        self.assertFalse(bz.logged_in,
+            "Login state check failed for logged out user.")
+
+
+    def test03NewBugBasic(self):
         """
         Create a bug with minimal amount of fields, then close it
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         component = "python-bugzilla"
         version = "rawhide"
         summary = ("python-bugzilla test basic bug %s" %
@@ -127,11 +129,11 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug.resolution, "NOTABUG")
 
 
-    def test4NewBugAllFields(self):
+    def test04NewBugAllFields(self):
         """
         Create a bug using all 'new' fields, check some values, close it
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
 
         summary = ("python-bugzilla test manyfields bug %s" %
                    datetime.datetime.today())
@@ -158,7 +160,7 @@ class RHPartnerTest(BaseTest):
         self.assertTrue(len(newout.splitlines()) == 3)
 
         bugid = int(newout.splitlines()[2])
-        bug = bz.getbug(bugid)
+        bug = bz.getbug(bugid, extra_fields=["sub_components"])
         print("\nCreated bugid: %s" % bugid)
 
         self.assertEquals(bug.summary, summary)
@@ -185,12 +187,17 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug.resolution, "WONTFIX")
         self.assertEquals(bug.alias, [alias])
 
+        # Check bug's minimal history
+        ret = bug.get_history_raw()
+        self.assertTrue(len(ret["bugs"]) == 1)
+        self.assertTrue(len(ret["bugs"][0]["history"]) == 1)
 
-    def test5ModifyStatus(self):
+
+    def test05ModifyStatus(self):
         """
         Modify status and comment fields for an existing bug
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         bugid = "663674"
         cmd = "bugzilla modify %s " % bugid
 
@@ -227,8 +234,8 @@ class RHPartnerTest(BaseTest):
         bug.refresh()
         self.assertEquals(bug.status, "CLOSED")
         self.assertEquals(bug.resolution, resolution)
-        self.assertEquals(bug.longdescs[-1]["is_private"], 1)
-        self.assertEquals(bug.longdescs[-1]["text"], comment)
+        self.assertEquals(bug.comments[-1]["is_private"], 1)
+        self.assertEquals(bug.comments[-1]["text"], comment)
 
         # Close bug as dup with no comment
         dupeid = "461686"
@@ -241,13 +248,31 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(len(bug.longdescs), desclen + 1)
         self.assertTrue("marked as a duplicate" in bug.longdescs[-1]["text"])
 
-        # Add lone comment
+        # bz.setstatus test
         comment = ("adding lone comment at %s" % datetime.datetime.today())
-        tests.clicomm(cmd + "--comment \"%s\" --private" % comment, bz)
-
+        bug.setstatus("POST", comment=comment, private=True)
         bug.refresh()
         self.assertEquals(bug.longdescs[-1]["is_private"], 1)
         self.assertEquals(bug.longdescs[-1]["text"], comment)
+        self.assertEquals(bug.status, "POST")
+
+        # bz.close test
+        fixed_in = str(datetime.datetime.today())
+        bug.close("ERRATA", fixedin=fixed_in)
+        bug.refresh()
+        self.assertEquals(bug.status, "CLOSED")
+        self.assertEquals(bug.resolution, "ERRATA")
+        self.assertEquals(bug.fixed_in, fixed_in)
+
+        # bz.addcomment test
+        comment = ("yet another test comment %s" % datetime.datetime.today())
+        bug.addcomment(comment, private=False)
+        bug.refresh()
+        self.assertEquals(bug.longdescs[-1]["text"], comment)
+        self.assertEquals(bug.longdescs[-1]["is_private"], 0)
+
+        # Confirm comments is same as getcomments
+        self.assertEquals(bug.comments, bug.getcomments())
 
         # Reset state
         tests.clicomm(cmd + "--status %s" % origstatus, bz)
@@ -255,11 +280,11 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug.status, origstatus)
 
 
-    def test6ModifyEmails(self):
+    def test06ModifyEmails(self):
         """
         Modify cc, assignee, qa_contact for existing bug
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         bugid = "663674"
         cmd = "bugzilla modify %s " % bugid
 
@@ -272,13 +297,14 @@ class RHPartnerTest(BaseTest):
         email2 = "crobinso@redhat.com"
         bug.deletecc(origcc)
         tests.clicomm(cmd + "--cc %s --cc %s" % (email1, email2), bz)
+        bug.addcc(email1)
 
         bug.refresh()
         self.assertTrue(email1 in bug.cc)
         self.assertTrue(email2 in bug.cc)
         self.assertEquals(len(bug.cc), 2)
 
-        tests.clicomm(cmd + "--cc -%s" % email1, bz)
+        tests.clicomm(cmd + "--cc=-%s" % email1, bz)
         bug.refresh()
         self.assertTrue(email1 not in bug.cc)
 
@@ -302,11 +328,11 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug.qa_contact, "extras-qa@fedoraproject.org")
 
 
-    def test7ModifyMultiFlags(self):
+    def test07ModifyMultiFlags(self):
         """
         Modify flags and fixed_in for 2 bugs
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         bugid1 = "461686"
         bugid2 = "461687"
         cmd = "bugzilla modify %s %s " % (bugid1, bugid2)
@@ -317,18 +343,30 @@ class RHPartnerTest(BaseTest):
                 ret.append(flag["name"] + flag["status"])
             return " ".join(sorted(ret))
 
-        def cleardict(b):
+        def cleardict_old(b):
+            """
+            Clear flag dictionary, for format meant for bug.updateflags
+            """
             clearflags = {}
             for flag in b.flags:
                 clearflags[flag["name"]] = "X"
             return clearflags
 
+        def cleardict_new(b):
+            """
+            Clear flag dictionary, for format meant for update_bugs
+            """
+            clearflags = []
+            for flag in b.flags:
+                clearflags.append({"name": flag["name"], "status": "X"})
+            return clearflags
+
         bug1 = bz.getbug(bugid1)
-        if cleardict(bug1):
-            bug1.updateflags(cleardict(bug1))
+        if cleardict_old(bug1):
+            bug1.updateflags(cleardict_old(bug1))
         bug2 = bz.getbug(bugid2)
-        if cleardict(bug2):
-            bug2.updateflags(cleardict(bug2))
+        if cleardict_old(bug2):
+            bug2.updateflags(cleardict_old(bug2))
 
 
         # Set flags and confirm
@@ -345,15 +383,15 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug1.get_flag_status("requires_doc_text"), "-")
 
         # Clear flags
-        if cleardict(bug1):
-            bug1.updateflags(cleardict(bug1))
+        if cleardict_new(bug1):
+            bz.update_flags(bug1.id, cleardict_new(bug1))
         bug1.refresh()
-        if cleardict(bug2):
-            bug2.updateflags(cleardict(bug2))
+        if cleardict_new(bug2):
+            bz.update_flags(bug2.id, cleardict_new(bug2))
         bug2.refresh()
 
-        self.assertEquals(cleardict(bug1), {})
-        self.assertEquals(cleardict(bug2), {})
+        self.assertEquals(cleardict_old(bug1), {})
+        self.assertEquals(cleardict_old(bug2), {})
 
         # Set "Fixed In" field
         origfix1 = bug1.fixed_in
@@ -363,7 +401,7 @@ class RHPartnerTest(BaseTest):
         if newfix == origfix2:
             newfix = origfix2 + "-2"
 
-        tests.clicomm(cmd + "--fixed_in %s" % newfix, bz)
+        tests.clicomm(cmd + "--fixed_in=%s" % newfix, bz)
 
         bug1.refresh()
         bug2.refresh()
@@ -371,7 +409,7 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug2.fixed_in, newfix)
 
         # Reset fixed_in
-        tests.clicomm(cmd + "--fixed_in \"-\"", bz)
+        tests.clicomm(cmd + "--fixed_in=\"-\"", bz)
 
         bug1.refresh()
         bug2.refresh()
@@ -379,10 +417,10 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug2.fixed_in, "-")
 
 
-    def test7ModifyMisc(self):
+    def test07ModifyMisc(self):
         bugid = "461686"
         cmd = "bugzilla modify %s " % bugid
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         bug = bz.getbug(bugid)
 
         # modify --dependson
@@ -392,7 +430,7 @@ class RHPartnerTest(BaseTest):
         tests.clicomm(cmd + "--dependson =111222", bz)
         bug.refresh()
         self.assertEquals([111222], bug.depends_on)
-        tests.clicomm(cmd + "--dependson -111222", bz)
+        tests.clicomm(cmd + "--dependson=-111222", bz)
         bug.refresh()
         self.assertEquals([], bug.depends_on)
 
@@ -408,7 +446,7 @@ class RHPartnerTest(BaseTest):
         tests.clicomm(cmd + "--keywords +Documentation --keywords EasyFix", bz)
         bug.refresh()
         self.assertEquals(["Documentation", "EasyFix"], bug.keywords)
-        tests.clicomm(cmd + "--keywords -EasyFix --keywords -Documentation",
+        tests.clicomm(cmd + "--keywords=-EasyFix --keywords=-Documentation",
                       bz)
         bug.refresh()
         self.assertEquals([], bug.keywords)
@@ -467,7 +505,7 @@ class RHPartnerTest(BaseTest):
         self.assertEquals(bug.cf_release_notes, "baz")
 
 
-    def test8Attachments(self):
+    def test08Attachments(self):
         tmpdir = "__test_attach_output"
         if tmpdir in os.listdir("."):
             os.system("rm -r %s" % tmpdir)
@@ -484,14 +522,14 @@ class RHPartnerTest(BaseTest):
         """
         Get and set attachments for a bug
         """
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         getallbugid = "663674"
         setbugid = "461686"
         cmd = "bugzilla attach "
         testfile = "../tests/data/bz-attach-get1.txt"
 
         # Add attachment as CLI option
-        setbug = bz.getbug(setbugid)
+        setbug = bz.getbug(setbugid, extra_fields=["attachments"])
         orignumattach = len(setbug.attachments)
 
         # Add attachment from CLI with mime guessing
@@ -500,7 +538,7 @@ class RHPartnerTest(BaseTest):
                              (setbugid, desc1, testfile), bz)
 
         desc2 = "python-bugzilla cli upload %s" % datetime.datetime.today()
-        out2 = tests.clicomm(cmd + "%s --file test --description \"%s\"" %
+        out2 = tests.clicomm(cmd + "%s --file test --summary \"%s\"" %
                              (setbugid, desc2), bz, stdin=open(testfile))
 
         # Expected output format:
@@ -508,10 +546,10 @@ class RHPartnerTest(BaseTest):
 
         setbug.refresh()
         self.assertEquals(len(setbug.attachments), orignumattach + 2)
-        self.assertEquals(setbug.attachments[-2]["description"], desc1)
+        self.assertEquals(setbug.attachments[-2]["summary"], desc1)
         self.assertEquals(setbug.attachments[-2]["id"],
                           int(out1.splitlines()[2].split()[2]))
-        self.assertEquals(setbug.attachments[-1]["description"], desc2)
+        self.assertEquals(setbug.attachments[-1]["summary"], desc2)
         self.assertEquals(setbug.attachments[-1]["id"],
                           int(out2.splitlines()[2].split()[2]))
         attachid = setbug.attachments[-2]["id"]
@@ -547,6 +585,7 @@ class RHPartnerTest(BaseTest):
 
         # Get all attachments
         getbug = bz.getbug(getallbugid)
+        getbug.autorefresh = True
         numattach = len(getbug.attachments)
         out = tests.clicomm(cmd + "--getall %s" % getallbugid, bz).splitlines()
 
@@ -559,8 +598,8 @@ class RHPartnerTest(BaseTest):
             os.unlink(f)
 
 
-    def test9Whiteboards(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+    def test09Whiteboards(self):
+        bz = self.bzclass(url=self.url)
         bug_id = "663674"
         cmd = "bugzilla modify %s " % bug_id
         bug = bz.getbug(bug_id)
@@ -584,35 +623,29 @@ class RHPartnerTest(BaseTest):
         # Modify whiteboards
         tests.clicomm(cmd +
                       "--whiteboard =foobar "
-                      "--qa_whiteboard _app ", bz)
-        bug.prependwhiteboard("pre-", "devel")
+                      "--qa_whiteboard _app "
+                      "--devel_whiteboard =pre-%s" % bug.devel_whiteboard, bz)
 
         bug.refresh()
         self.assertEquals(bug.qa_whiteboard, initval + "qa" + " _app")
-        self.assertEquals(bug.devel_whiteboard, "pre- " + initval + "devel")
+        self.assertEquals(bug.devel_whiteboard, "pre-" + initval + "devel")
         self.assertEquals(bug.status_whiteboard, "foobar")
 
         # Verify that tag manipulation is smart about separator
         tests.clicomm(cmd +
-                      "--qa_whiteboard -_app "
-                      "--internal_whiteboard -security", bz)
+                      "--qa_whiteboard=-_app "
+                      "--internal_whiteboard=-security,", bz)
         bug.refresh()
 
         self.assertEquals(bug.qa_whiteboard, initval + "qa")
         self.assertEquals(bug.internal_whiteboard,
                           initval + "internal, foo security1")
 
-        bug.addtag("teststuff", "internal")
-        bug.refresh()
-        self.assertEquals(bug.internal_whiteboard,
-                          initval + "internal, foo security1, teststuff")
-
-
         # Clear whiteboards
-        bug.setwhiteboard("", "status")
-        bug.setwhiteboard("", "qa")
-        bug.setwhiteboard("", "devel")
-        bug.setwhiteboard("", "internal")
+        update = bz.build_update(
+            whiteboard="", devel_whiteboard="",
+            internal_whiteboard="", qa_whiteboard="")
+        bz.update_bugs(bug.id, update)
 
         bug.refresh()
         self.assertEquals(bug.whiteboard, "")
@@ -625,73 +658,123 @@ class RHPartnerTest(BaseTest):
         """
         Failed login test, gives us a bit more coverage
         """
-        ret = tests.clicomm("bugzilla --bugzilla %s "
-                            "--user foobar@example.com "
-                            "--password foobar login" % self.url, None,
-                            expectfail=True)
-        self.assertTrue("Login failed: " in ret)
+        # We overwrite getpass for testing
+        import getpass
+
+        def fakegetpass(prompt):
+            sys.stdout.write(prompt)
+            sys.stdout.flush()
+            return sys.stdin.readline()
+        oldgetpass = getpass.getpass
+        getpass.getpass = fakegetpass
+
+        try:
+            # Implied login with --username and --password
+            ret = tests.clicomm("bugzilla --bugzilla %s "
+                                "--user foobar@example.com "
+                                "--password foobar query -b 123456" % self.url,
+                                None, expectfail=True)
+            self.assertTrue("Login failed: " in ret)
+
+            # 'login' with explicit options
+            ret = tests.clicomm("bugzilla --bugzilla %s "
+                                "--user foobar@example.com "
+                                "--password foobar login" % self.url,
+                                None, expectfail=True)
+            self.assertTrue("Login failed: " in ret)
+
+            # 'login' with positional options
+            ret = tests.clicomm("bugzilla --bugzilla %s "
+                                "login foobar@example.com foobar" % self.url,
+                                None, expectfail=True)
+            self.assertTrue("Login failed: " in ret)
 
 
-    def test10LoginState(self):
-        bz = self.bzclass(url=self.url, cookiefile=None, tokenfile=None)
-        self.assertFalse(bz.logged_in,
-            "Login state check failed for logged out user.")
-
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
-        self.assertTrue(bz.logged_in,
-            "Login state check failed for logged in user.")
+            # bare 'login'
+            stdinstr = "foobar@example.com\n\rfoobar\n\r"
+            ret = tests.clicomm("bugzilla --bugzilla %s login" % self.url,
+                                None, expectfail=True, stdinstr=stdinstr)
+            self.assertTrue("Bugzilla Username:" in ret)
+            self.assertTrue("Bugzilla Password:" in ret)
+            self.assertTrue("Login failed: " in ret)
+        finally:
+            getpass.getpass = oldgetpass
 
 
     def test11UserUpdate(self):
         # This won't work if run by the same user we are using
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         email = "anaconda-maint-list@redhat.com"
         group = "fedora_contrib"
 
         fn = sys._getframe().f_code.co_name  # pylint: disable=protected-access
-        if not self._check_have_admin(bz, fn):
-            return
+        have_admin = self._check_have_admin(bz, fn)
 
         user = bz.getuser(email)
-        self.assertTrue(group in user.groupnames)
+        if have_admin:
+            self.assertTrue(group in user.groupnames)
         origgroups = user.groupnames
 
         # Remove the group
-        bz.updateperms(email, "remove", [group])
-        user.refresh()
-        self.assertTrue(group not in user.groupnames)
+        try:
+            bz.updateperms(email, "remove", [group])
+            user.refresh()
+            self.assertTrue(group not in user.groupnames)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
 
         # Re add it
-        bz.updateperms(email, "add", group)
-        user.refresh()
-        self.assertTrue(group in user.groupnames)
+        try:
+            bz.updateperms(email, "add", group)
+            user.refresh()
+            self.assertTrue(group in user.groupnames)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
 
         # Set groups
-        newgroups = user.groupnames[:]
-        newgroups.remove(group)
-        bz.updateperms(email, "set", newgroups)
-        user.refresh()
-        self.assertTrue(group not in user.groupnames)
+        try:
+            newgroups = user.groupnames[:]
+            if have_admin:
+                newgroups.remove(group)
+            bz.updateperms(email, "set", newgroups)
+            user.refresh()
+            self.assertTrue(group not in user.groupnames)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
 
         # Reset everything
-        bz.updateperms(email, "set", origgroups)
+        try:
+            bz.updateperms(email, "set", origgroups)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
+
         user.refresh()
         self.assertEqual(user.groupnames, origgroups)
 
 
     def test11ComponentEditing(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         component = ("python-bugzilla-testcomponent-%s" %
                      str(random.randint(1, 1024 * 1024 * 1024)))
         basedata = {
-            "product": "Virtualization Tools",
+            "product": "Fedora Documentation",
             "component": component,
         }
 
         fn = sys._getframe().f_code.co_name  # pylint: disable=protected-access
-        if not self._check_have_admin(bz, fn):
-            return
-
+        have_admin = self._check_have_admin(bz, fn)
 
         def compare(data, newid):
             proxy = bz._proxy  # pylint: disable=protected-access
@@ -721,10 +804,17 @@ class RHPartnerTest(BaseTest):
             "initialcclist": ["wwoods@redhat.com", "toshio@fedoraproject.org"],
             "is_active": True,
         })
-        newid = bz.addcomponent(data)['id']
-        print("Created product=%s component=%s" % (
-            basedata["product"], basedata["component"]))
-        compare(data, newid)
+        try:
+            newid = bz.addcomponent(data)['id']
+            print("Created product=%s component=%s" % (
+                basedata["product"], basedata["component"]))
+            compare(data, newid)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
+
 
         # Edit component
         data = basedata.copy()
@@ -736,16 +826,18 @@ class RHPartnerTest(BaseTest):
                               "virt-maint@lists.fedoraproject.org"],
             "is_active": False,
         })
-        bz.editcomponent(data)
-        compare(data, newid)
+        try:
+            bz.editcomponent(data)
+            compare(data, newid)
+        except:
+            e = sys.exc_info()[1]
+            if have_admin:
+                raise
+            self.assertTrue("Sorry, you aren't a member" in str(e))
 
     def test12SetCookie(self):
-        bz = self.bzclass("partner-bugzilla.redhat.com",
-            cookiefile=cf, tokenfile=None)
-
-        fn = sys._getframe().f_code.co_name  # pylint: disable=protected-access
-        if not self._check_rh_privs(bz, "cookie", fn):
-            return
+        bz = self.bzclass(self.url,
+            cookiefile=-1, tokenfile=None)
 
         try:
             bz.cookiefile = None
@@ -758,13 +850,13 @@ class RHPartnerTest(BaseTest):
         bz.disconnect()
         bz.cookiefile = None
         bz.connect()
-        self.assertFalse(bool(self._check_rh_privs(
-            bz, "", "cookie", quiet=True)))
+        self.assertFalse(bz.logged_in)
 
     def test13SubComponents(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         # Long closed RHEL5 lvm2 bug. This component has sub_components
         bug = bz.getbug("185526")
+        bug.autorefresh = True
         self.assertEquals(bug.component, "lvm2")
 
         bz.update_bugs(bug.id, bz.build_update(
@@ -777,72 +869,33 @@ class RHPartnerTest(BaseTest):
         bug.refresh()
         self.assertEqual(bug.sub_components, {})
 
+    def test13ExternalTrackerQuery(self):
+        bz = self.bzclass(url=self.url)
+        self.assertRaises(RuntimeError,
+                          bz.build_external_tracker_boolean_query)
+
     def _deleteAllExistingExternalTrackers(self, bugid):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         ids = [bug['id'] for bug in bz.getbug(bugid).external_bugs]
         if ids != []:
             bz.remove_external_tracker(ids=ids)
 
-    def test14ExternalTrackersQuery(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
-        bugid = 461686
-        ext_bug_id = 1234659
-
-        # Delete any existing external trackers to get to a known state
-        self._deleteAllExistingExternalTrackers(bugid)
-
-        # test adding tracker
-        kwargs = {
-            'ext_type_url': 'http://bugzilla.mozilla.org',
-            'ext_type_description': 'Mozilla Foundation',
-            'ext_status': 'Original Status',
-        }
-
-        # Add a tracker that we can query for
-        bz.add_external_tracker(bugid, ext_bug_id, **kwargs)
-
-        kwargs['ext_bz_bug_id'] = ext_bug_id
-
-        boolean_query = bz.build_external_tracker_boolean_query(
-            ext_bz_bug_id=ext_bug_id)
-        query_results = bz.query(bz.build_query(boolean_query=boolean_query))
-        if len(query_results) != 1:
-            raise AssertionError(
-                'external tracker query by bug id should return 1 result.')
-        for key, value in kwargs.items():
-            assert kwargs[key] == value
-
-        boolean_query = bz.build_external_tracker_boolean_query(
-            ext_type_description=kwargs['ext_type_description'])
-        query_results = bz.query(bz.build_query(boolean_query=boolean_query))
-        assert bugid in [qr.id for qr in query_results]
-
-        boolean_query = bz.build_external_tracker_boolean_query(
-            ext_status=kwargs['ext_status'])
-        query_results = bz.query(bz.build_query(boolean_query=boolean_query))
-        if len(query_results) != 1:
-            raise AssertionError(
-                'external tracker query by status should return 1 result.')
-        for key, value in kwargs.items():
-            assert kwargs[key] == value
-
-        boolean_query = bz.build_external_tracker_boolean_query(
-            ext_type_url=kwargs['ext_type_url'])
-        query_results = bz.query(bz.build_query(boolean_query=boolean_query))
-        assert bugid in [qr.id for qr in query_results]
-
     def test14ExternalTrackersAddUpdateRemoveQuery(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         bugid = 461686
         ext_bug_id = 380489
 
         # Delete any existing external trackers to get to a known state
         self._deleteAllExistingExternalTrackers(bugid)
 
+        url = "https://bugzilla.mozilla.org"
+        if bz.bz_ver_major < 5:
+            url = "http://bugzilla.mozilla.org"
+
         # test adding tracker
         kwargs = {
             'ext_type_id': 6,
-            'ext_type_url': 'http://bugzilla.mozilla.org',
+            'ext_type_url': url,
             'ext_type_description': 'Mozilla Foundation',
             'ext_status': 'Original Status',
             'ext_description': 'the description',
@@ -880,6 +933,29 @@ class RHPartnerTest(BaseTest):
         assert len(ids) == 0
 
     def test15EnsureLoggedIn(self):
-        bz = self.bzclass(url=self.url, cookiefile=cf, tokenfile=tf)
+        bz = self.bzclass(url=self.url)
         comm = "bugzilla --ensure-logged-in query --bug_id 979546"
         tests.clicomm(comm, bz)
+
+    def test16ModifyTags(self):
+        bugid = "461686"
+        cmd = "bugzilla modify %s " % bugid
+        bz = self.bzclass(url=self.url)
+        bug = bz.getbug(bugid)
+
+        if bug.tags:
+            bz.update_tags(bug.id, tags_remove=bug.tags)
+            bug.refresh()
+            self.assertEquals(bug.tags, [])
+
+        tests.clicomm(cmd + "--tags foo --tags +bar --tags baz", bz)
+        bug.refresh()
+        self.assertEquals(bug.tags, ["foo", "bar", "baz"])
+
+        tests.clicomm(cmd + "--tags=-bar", bz)
+        bug.refresh()
+        self.assertEquals(bug.tags, ["foo", "baz"])
+
+        bz.update_tags(bug.id, tags_remove=bug.tags)
+        bug.refresh()
+        self.assertEquals(bug.tags, [])
